import { EventFormatter } from './../util';
import { Channel } from './channel';
import { SCClientSocket } from "socketcluster-client";
import { SCChannel } from "sc-channel";
/**
 * This class represents a Socket Cluster channel.
 */
export declare class SocketClusterChannel extends Channel {
    /**
     * The SocketCluster client instance.
     */
    socket: SCClientSocket;
    /**
     * The name of the channel.
     */
    name: any;
    /**
     * Channel options.
     */
    options: any;
    /**
     * The event formatter.
     */
    eventFormatter: EventFormatter;
    /**
     * The event callbacks applied to the channel.
     */
    events: any;
    channelObject: SCChannel;
    connectedOnce: boolean;
    /**
     * Create a new class instance.
     */
    constructor(socket: SCClientSocket, name: string, options: any);
    /**
     * Subscribe to a socket-cluster channel.
     */
    subscribe(): void;
    getFullAuthEndpoint(): string;
    /**
     * Unsubscribe from channel and ubind event callbacks.
     */
    unsubscribe(): void;
    /**
     * Listen for an event on the channel instance.
     */
    listen(event: string, callback: Function): SocketClusterChannel;
    /**
     * Stop listening for an event on the channel instance.
     */
    stopListening(event: string): SocketClusterChannel;
    /**
     * Bind the channel's socket to an event and store the callback.
     */
    on(event: string, callback: Function): void;
    /**
     * Attach a 'reconnect' listener and bind the event.
     */
    configureReconnector(): void;
    /**
     * Bind the channel's socket to an event and store the callback.
     */
    bind(event: string, callback: Function): void;
    /**
     * Unbind the channel's socket from all stored event callbacks.
     */
    unbind(): void;
}
